@@ -85,9 +85,9 @@ def get_top_terms(tfidf, n):
 
 def doc_to_vec(doc_prep):
     document_vec = {}
-    document_norm=norm(doc_prep)
+    length = sum(doc_prep.values())
     for term in doc_prep:
-        document_vec[term] = doc_prep[term] / document_norm
+        document_vec[term] = doc_prep[term] / length
     return document_vec
 
 
@@ -97,9 +97,6 @@ def get_esa_matrix(top_n, tfidf, concepts):
         esa_matrix[concept] = {term : 0.0 for term in list(top_n[concept])}
         for term  in list(top_n[concept]):
             esa_matrix[concept][term] = tfidf.loc[concept, term]
-        concept_norm= norm(esa_matrix[concept])
-        for term in list(top_n[concept]):
-            esa_matrix[concept][term] = esa_matrix[concept][term]/concept_norm
     return esa_matrix
 
 
@@ -119,7 +116,7 @@ def max_sim(model, document_vec, concept_vec):
         matched_term = None
         for term_2 in concept_vec:
             comparisons += 1
-            current_similarity = 1
+            current_similarity = model.similarity(term_1, term_2)
             if current_similarity > max_similarity:
                 max_similarity = current_similarity
                 matched_term = term_2
@@ -128,7 +125,7 @@ def max_sim(model, document_vec, concept_vec):
             else:
                 continue
         if matched_term != None:
-            similarity += (document_vec[term_1] )
+            similarity += (document_vec[term_1] * concept_vec[matched_term]) * max_similarity
     similarity /=  norm(document_vec) * norm(concept_vec)
     end_time = time.time()
     return (similarity, comparisons, end_time - start_time)
@@ -164,9 +161,22 @@ def initialize_model(path_corpus,path_model,path_model_vocab,n):
         idfs = compute_idf(preprocessed, concepts, terms)
         tfidf = compute_tfidf(tf, idfs, terms)
         top_n = get_top_terms(tfidf, n)
-        esa_matrix = get_esa_matrix(top_n, tfidf, concepts)
+        top_n_terms= set()
+        for concept in top_n.index:
+            top_n_terms.add(top_n[concept])
+        top_n_terms = tuple(top_n_terms)
+        top_n_bows= [bows[term] for term in top_n_terms]
+        top_n_preprocessed={}
+        for concept in preprocessed:
+            top_n_preprocessed[concept]={}
+            for term in preprocessed[concept]:
+                if term in top_n_terms:
+                    top_n_preprocessed[term]=preprocessed[concept][term]
+        top_n_tf = compute_tf(top_n_preprocessed, concepts, top_n_bows, top_n_terms)
+        top_n_tfidf=compute_tfidf(top_n_tf,idfs,top_n_terms)
+        esa_matrix = get_esa_matrix(top_n, top_n_tfidf, concepts)
         model = gensim.models.keyedvectors.KeyedVectors.load_word2vec_format(path_model, binary = True)
-
+        model.init_sims(replace=True)
 def model_topic(path_corpus,path_model,path_model_vocab,text,n):
     if n == -1:
         n = None
